@@ -2,7 +2,7 @@
    This file is part of potrace. It is free software and it is covered
    by the GNU general public license. See the file COPYING for details. */
 
-/* $Id: main.c,v 1.29 2004/03/06 06:14:28 selinger Exp $ */
+/* $Id: main.c,v 1.30 2004/06/20 15:30:30 selinger Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -20,8 +20,6 @@
 #include "curve.h"
 #include "path.h"
 #include "bitmap.h"
-#include "ztops.h"
-#include "have_compress.h"
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -207,13 +205,8 @@ static int usage(FILE *f) {
   fprintf(f, " --group                    - group related paths together\n");
   fprintf(f, "Postscript/EPS options:\n");
   fprintf(f, " -P, --pagesize <format>    - page size (default is "DEFAULT_PAPERFORMAT")\n");
-  if (have_compress()==1) {
-    fprintf(f, " -c, --cleartext            - do not compress the output\n");
-    fprintf(f, " -2, --level2               - use postscript level 2 compression (default)\n");
-  } else {
-    fprintf(f, " -c, --cleartext            - do not compress the output (default)\n");
-    fprintf(f, " -2, --level2               - use postscript level 2 compression (disabled)\n");
-  }
+  fprintf(f, " -c, --cleartext            - do not compress the output\n");
+  fprintf(f, " -2, --level2               - use postscript level 2 compression (default)\n");
 #ifdef HAVE_ZLIB
   fprintf(f, " -3, --level3               - use postscript level 3 compression\n");
 #endif
@@ -415,11 +408,7 @@ static int dopts(int ac, char *av[]) {
   info.paperheight = DEFAULT_PAPERHEIGHT;
   info.turdsize = 2;
   info.unit = 10;
-  if (have_compress()==1) {
-    info.compress = 1;
-  } else {
-    info.compress = 0;
-  }
+  info.compress = 1;
   info.pslevel = 2;
   info.color = 0x000000;
   info.turnpolicy = POLICY_MINORITY;
@@ -604,21 +593,17 @@ static int dopts(int ac, char *av[]) {
       info.compress = 0;
       break;
     case '2':
-      if (have_compress()==1) {
-	info.pslevel = 2;
-	info.compress = 1;
-      } else {
-	fprintf(stderr, ""POTRACE": option -2 not supported due to patent restrictions, ignoring.\n");
-	info.pslevel = 2;
-	info.compress = 0;
-      }
+      info.pslevel = 2;
+      info.compress = 1;
       break;
     case '3':
 #ifdef HAVE_ZLIB
       info.pslevel = 3;
       info.compress = 1;
 #else
-      fprintf(stderr, ""POTRACE": option -3 not supported, ignoring.\n");
+      fprintf(stderr, ""POTRACE": option -3 not supported, using -2 instead.\n");
+      info.pslevel = 2;
+      info.compress = 1;
 #endif
       break;
     case 'e':
